@@ -83,7 +83,7 @@ class MainWindow(QMainWindow, WindowMixin):
         self.setWindowTitle(__appname__)
         #QtGui.QMainWindow.__init__(self)
         #self.show()
-        # Jonathan. Parámetros de configuración
+
         # -----------------------------------------------------------------
         # Load setting in the main thread
         self.settings = Settings()
@@ -124,20 +124,10 @@ class MainWindow(QMainWindow, WindowMixin):
         self.shapesToItems = {}
         self.prevLabelText = ''
 
-        # -----------------------------------------------------------------
-        # Jonathan. Comienza creando el elemento que contiene la lista de
-        # las anotaciones (lo que aparece arriba a la derecha)
-        # -----------------------------------------------------------------
-        # Crea primero un layout donde irá añadiendo cosas.
+
         listLayout = QVBoxLayout()
         listLayout.setContentsMargins(0, 0, 0, 0)
 
-        # De aquí hay muchas cosas que creo que se pueden eliminar.
-        # Crea un checkbox para la etiqueta por defecto
-        # Si queremos que use siempre la misma hay que modificar el método
-        # newshape para que no pregunte. Como vamos a tener dos etiquetas
-        # estoma y region, modificaría el método newshape para que tome
-        # un valor adicional que sea la etiqueta.
         self.useDefaultLabelCheckbox = QCheckBox(getStr('useDefaultLabel'))
         self.useDefaultLabelCheckbox.setChecked(False)
         self.defaultLabelTextLine = QLineEdit()
@@ -147,18 +137,12 @@ class MainWindow(QMainWindow, WindowMixin):
         useDefaultLabelContainer = QWidget()
         useDefaultLabelContainer.setLayout(useDefaultLabelQHBoxLayout)
 
-        # Crea un widget para la opción anotación dificil. Creo que se puede
-        # eliminar. Nada más que hay que ir en cascada, y tener en cuenta cuando
-        # están marcados.
         self.diffcButton = QCheckBox(getStr('useDifficult'))
         self.diffcButton.setChecked(False)
         self.diffcButton.stateChanged.connect(self.btnstate)
         self.editButton = QToolButton()
         self.editButton.setToolButtonStyle(Qt.ToolButtonTextBesideIcon)
 
-        # Importante.
-        # Añade los elementos a la lista. Comentando estas tres líneas queda más
-        # limpio, y solo aparece la lista de anotaciones.
         # listLayout.addWidget(self.editButton)
         # listLayout.addWidget(self.diffcButton)
         # listLayout.addWidget(useDefaultLabelContainer)
@@ -178,11 +162,7 @@ class MainWindow(QMainWindow, WindowMixin):
         self.dock.setObjectName(getStr('labels'))
         self.dock.setWidget(labelListContainer)
 
-        # -----------------------------------------------------------------
-        # Jonathan. A continuación se crea la lista de ficheros. (lo que
-        # aparece abajo a la derecha). Realmente es un layout que tiene una
-        # lista.
-        # -----------------------------------------------------------------
+
         self.fileListWidget = QListWidget()
         self.fileListWidget.itemDoubleClicked.connect(self.fileitemDoubleClicked)
         filelistLayout = QVBoxLayout()
@@ -194,10 +174,7 @@ class MainWindow(QMainWindow, WindowMixin):
         self.filedock.setObjectName(getStr('files'))
         self.filedock.setWidget(fileListContainer)
 
-        # -----------------------------------------------------------------
-        # Jonathan. A continuación se crea la zona central que va a ser la
-        # encargada de gestionar la imagen. Esto no hay que tocar nada.
-        # -----------------------------------------------------------------
+
         self.zoomWidget = ZoomWidget()
         self.colorDialog = ColorDialog(parent=self)
 
@@ -228,15 +205,6 @@ class MainWindow(QMainWindow, WindowMixin):
         self.dockFeatures = QDockWidget.DockWidgetClosable | QDockWidget.DockWidgetFloatable
         self.dock.setFeatures(self.dock.features() ^ self.dockFeatures)
 
-        # ******************************************************************
-        # A partir de aquí, empieza código a modificar.
-        # ******************************************************************
-
-        # -----------------------------------------------------------------
-        # Jonathan. A continuación se definen las acciones que van a incluir
-        # los distintos menús. Yo aquí no tocaría nada, sino que añadiría al
-        # final las nuestras.
-        # -----------------------------------------------------------------
         action = partial(newAction, self)
         quit = action(getStr('quit'), self.close,
                       'Ctrl+q', 'quit', getStr('quitApp'))
@@ -292,7 +260,7 @@ class MainWindow(QMainWindow, WindowMixin):
         create = action(getStr('crtBox'), self.createShape,
                         'r', 'new', getStr('crtBoxDetail'), enabled=False)
 
-        # Importante. Acción añadida para añadir regiones.
+
         createRegion = action('Add surface', self.createShapeRegion,
                               'w', 'new', getStr('crtBoxDetail'), enabled=False)
 
@@ -380,11 +348,7 @@ class MainWindow(QMainWindow, WindowMixin):
         self.drawSquaresOption.setChecked(settings.get(SETTING_DRAW_SQUARE, False))
         self.drawSquaresOption.triggered.connect(self.toogleDrawSquare)
 
-        # -----------------------------------------------------------------
-        # Jonathan. Todas las acciones que se han definido deben añadirse
-        # al siguiente diccinoario para poder ser utilizadas luego, yo
-        # he añadido lo de createRegion.
-        # -----------------------------------------------------------------
+
 
         self.actions = struct(save=save, save_format=save_format, saveAs=saveAs, open=open, close=close,
                               resetAll=resetAll,
@@ -407,11 +371,6 @@ class MainWindow(QMainWindow, WindowMixin):
                                   close, create, createMode, editMode),
                               onShapesPresent=(saveAs, hideAll, showAll))
 
-        # -----------------------------------------------------------------
-        # Jonathan. Aquí se va a definir cada uno de los menús.
-        # Me he cargado el menú Edit pero manteniendo la barra de
-        # herramientas lateral
-        # -----------------------------------------------------------------
 
         self.menus = struct(
             file=self.menu('&File'),
@@ -432,17 +391,9 @@ class MainWindow(QMainWindow, WindowMixin):
         self.autoSaving = QAction(getStr('autoSaveMode'), self)
         self.autoSaving.setCheckable(True)
 
-        # Jónathan. Al activar el autosave mode, al abrir un directorio te pide que
-        # indiques el directorio donde se van a guardar las imágenes. Se podría cambiar para
-        # que fuera el mismo donde están dichas imágenes.
-
-        # Jónathan. Definición menú view
-        # Como hay botones especiales que necesitan checkbox se definen de esta manera.
-        # Sino bastaría con añadir las acciones al menú.
         self.autoSaving.setChecked(settings.get(SETTING_AUTO_SAVE, True))
 
 
-
         # Sync single class mode from PR#106
         self.singleClassMode = QAction(getStr('singleClsMode'), self)
         self.singleClassMode.setShortcut("Ctrl+Shift+S")
@@ -455,7 +406,7 @@ class MainWindow(QMainWindow, WindowMixin):
         self.displayLabelOption.setCheckable(True)
         self.displayLabelOption.setChecked(settings.get(SETTING_PAINT_LABEL, False))
         self.displayLabelOption.triggered.connect(self.togglePaintLabelsOption)
-        # Jónathan. Del menú view he quitado lo de advanced mode, para que no se pueda cambiar.
+
         # addActions(self.menus.view, (
         #     self.autoSaving,
         #     self.singleClassMode,
@@ -465,15 +416,14 @@ class MainWindow(QMainWindow, WindowMixin):
         #     zoomIn, zoomOut, zoomOrg, None,
         #     fitWindow, fitWidth))
 
-        # Jónathan. Definición menú file
+
         addActions(self.menus.file,
                    (open, opendir, quit))
-        # Jónathan. Definición menú help
+
         addActions(self.menus.help, (help, showInfo))
 
         self.menus.file.aboutToShow.connect(self.updateFileMenu)
 
-        # Definición del menú edit stoma
         addActions(self.menus.stoma, (create, createRegion, detect, createScale, excel, trainModel,close))
 
         # Custom context menu for the canvas widget:
@@ -482,27 +432,14 @@ class MainWindow(QMainWindow, WindowMixin):
             action('&Copy here', self.copyShape),
             action('&Move here', self.moveShape)))
 
-        # -----------------------------------------------------------------
-        # Jónathan. Se define el toolbar.
-        # -----------------------------------------------------------------
         self.tools = self.toolbar('Tools')
-        # Jónathan. Las acciones que se van añadir al toolbar son las que aparecen a continuación.
-        # Dependiendo del modo se muestran unas u otras, pero en nuestro caso solo va a haber modo
-        # beginner.
+
         self.actions.beginner = (
             open, opendir, openNextImg, openPrevImg,None, save,  detect,excel,trainModel,None,create, createRegion, createScale, delete)
 
-        # Como solo hay modo beginner esto se puede quedar como una lista vacía.
         self.actions.advanced = ()
 
-        # ******************************************************************
-        # Aquí termina código a modificar. Salvo luego las nuevas funciones
-        # que se definan.
-        # ******************************************************************
 
-        # -----------------------------------------------------------------
-        # Jónathan. Más parámetros de cofiguración. No hace falta tocarlos.
-        # -----------------------------------------------------------------
         self.statusBar().showMessage('%s started.' % __appname__)
         self.statusBar().show()
         self.image = QImage()
@@ -723,9 +660,7 @@ class MainWindow(QMainWindow, WindowMixin):
         msg = u'Name:{0} \nApp Version:{1} \n{2} '.format(__appname__, __version__, sys.version_info)
         QMessageBox.information(self, u'Information', msg)
 
-    # Jónathan. Importante.
-    # Definimos dos funciones, una para añadir regiones y otra para añadir estomas. La diferencia es el texto
-    # por defecto que fija cada una de ellas.
+
     def createShape(self):
         assert self.beginner()
         self.text = 'stoma'
@@ -750,7 +685,6 @@ class MainWindow(QMainWindow, WindowMixin):
         self.canvas.setEditing(False)
         self.actions.create.setEnabled(False)
         self.actions.createScale.setEnabled(False)
-        #una vez que hemos añadido la escala activamos la posibilidad de generar un excel
         self.actions.excel.setEnabled(True)
         self.saveFile()
 
@@ -813,7 +747,6 @@ class MainWindow(QMainWindow, WindowMixin):
             item.setBackground(generateColorByText(text))
             self.setDirty()
 
-    # Tzutalin 20160906 : Add file list and dock to move faster
     def fileitemDoubleClicked(self, item=None):
         currIndex = self.mImgList.index(ustr(item.text()))
         if currIndex < len(self.mImgList):
@@ -976,14 +909,12 @@ class MainWindow(QMainWindow, WindowMixin):
             self.canvas.setShapeVisible(shape, item.checkState() == Qt.Checked)
 
     # Callback functions:
-    # Importante.
+    # Importante. 
     def newShapeStoma(self, text='stoma'):
         """Pop-up and give focus to the label editor.
 
         position MUST be in global coordinates.
         """
-        # Jónathan.
-        # Estas líneas las he comentado yo.
         # if not self.useDefaultLabelCheckbox.isChecked() or not self.defaultLabelTextLine.text():
         #    if len(self.labelHist) > 0:
         #        self.labelDialog = LabelDialog(
@@ -1019,14 +950,12 @@ class MainWindow(QMainWindow, WindowMixin):
             # self.canvas.undoLastLine()
             self.canvas.resetAllLines()
 
-    # Importante.
     def newShape(self):
         """Pop-up and give focus to the label editor.
 
         position MUST be in global coordinates.
         """
-        # Jónathan.
-        # Estas líneas las he comentado yo.
+
         # if not self.useDefaultLabelCheckbox.isChecked() or not self.defaultLabelTextLine.text():
         #    if len(self.labelHist) > 0:
         #        self.labelDialog = LabelDialog(
@@ -1480,12 +1409,11 @@ class MainWindow(QMainWindow, WindowMixin):
         x = Dialog.exec_()
         if ui.genera:
             if ui.default_1:#if it is by default
-                # Detectamos estomas automáticamente, para ello vamos a usar las funciones del archivo detectStoma.py. Por eso
-                # tenemos que diferenciar si hemos seleccionamos una imagen o un cjto.
                 if len(self.mImgList) <= 1:
                     path = os.path.dirname(ustr(self.filePath)) if self.filePath else '.'
                     imgFileName = os.path.basename(self.filePath)
                     img = os.path.join(path, imgFileName)
+                    print(img)
                     detectStoma.mainImage(img)
                     if isinstance(img, (tuple, list)):
                         img = img[0]
@@ -1526,9 +1454,6 @@ class MainWindow(QMainWindow, WindowMixin):
         ui = Ui_Dialog()
         ui.setupUi(Dialog)
         x = Dialog.exec_()
-        # El proceso principal se queda esperando hasta que el dialogo se cierra.
-        # Una vez que el dialogo se ha cerrado podemos entrar a uno de los parámetros
-        # de ese dialogo.
         #print(ui.es)
         if ui.genera:
             generaExcel(os.path.dirname(ustr(self.filePath)), ui.esca, self.shapeSize, ui.uni, ui.che2, ui.che3, ui.che4, ui.che5, ui.che6, ui.che7, ui.che8, ui.che9, ui.che10)
@@ -1552,9 +1477,6 @@ class MainWindow(QMainWindow, WindowMixin):
         #ui = notebooks.notebookmenu.Ui_Dialog()
         #ui.setupUi(Dialog)
         #x = Dialog.exec_()
-        # El proceso principal se queda esperando hasta que el dialogo se cierra.
-        # Una vez que el dialogo se ha cerrado podemos entrar a uno de los parámetros
-        # de ese dialogo.
         #if ui.genera:
         path = os.path.dirname(ustr(self.filePath)) if self.filePath else '.'
             #tecnhiques = notebooks.mainModel.selectTecniques(self, ui.avg, ui.bila, ui.blur, ui.chanhsv, ui.chanlab, ui.crop,
@@ -1786,4 +1708,4 @@ def main():
 
 
 if __name__ == '__main__':
-    sys.exit(main())
\ No newline at end of file
+    sys.exit(main())
